import Taro, { Component } from '@tarojs/taro'
import { View, ScrollView, Block } from '@tarojs/components'
import './index.scss'
import Blank from '../../components/Blank'
import HouseCard from '../../components/HouseCard'
import ready from '@/utils/ready'
import { connect } from '@tarojs/redux'
import * as houseActions from '@/actions/house'

function noop(){}

@connect(
  ({ user, house }) => ({ ...user, house }),
  {...houseActions}
)
export default class extends Component {
  config = {
    navigationBarTitleText: '添加预选房源',
  }

  state = {}

  componentWillMount() {
    ready.queue(() => {
      const { userInfo, house } = this.props
      const { salesBatchId } = this.$router.params

      if (!house.mySelectHouses || !house.mySelectHouses.length) {
        this.props.dispatchGetMySelection({
          salesBatchId,
          personId: userInfo.person.personId,
        })
      }
    })
  }

  handleCheckboxChange = (e) => {
    console.log('------------->', e)
  }

  renderHead() {
    return (
      <View className="head">仅展示符合认筹条件的已预选房源,左侧勾选</View>
    );
  }

  renderHouses() {
    const { house } = this.props
    const hasData = house.mySelectHouses && house.mySelectHouses.length

    return hasData && (
      <Block>
        <ScrollView scrollY className="container">
          <CheckboxGroup onChange={this.handleCheckboxChange}>
            {
              house.mySelectHouses.map((item) => {
                const checked = !!house.raiseCart.filter(x => x.houseId == item.houseId)[0]
                return (
                  <Label class="checkbox" key={item.houseId}>
                    <Checkbox value={item.houseId} checked={checked} >
                      <View className="carditem" >
                        <HouseCard summary={item} onClick={noop} />
                      </View>
                    </Checkbox>
                  </Label>
                )
              })
            }
          </CheckboxGroup>
        </ScrollView >
        <View className="raise-box"> <View className="raise-btn">确认以上选择</View></View>
      </Block>
    )
  }


  renderBlank() {
    const { house } = this.props
    const hasData = house.mySelectHouses && house.mySelectHouses.length

    return !hasData && (
      <Blank tips="没有符合认筹条件的预选房源" />
    )
  }

  render() {
    return (
      <View className="add-house">
        {this.renderHead()}
        {this.renderBlank()}
        {this.renderHouses()}
      </View>
    )
  }
}